@@ -13,9 +13,8 @@ class PyLookout:
     def __init__(
         self,
         threshold=75,
-        method="sendgrid",
+        method="local",
         check_containers=False,
-        background=False,
     ):
         logging.basicConfig(
             format="%(asctime)s %(message)s",
@@ -28,7 +27,7 @@ class PyLookout:
 
         self.logger = logging.getLogger()
         self.info = Collector(check_containers)
-        self.logger.info("Informaton collected successfully!")
+        self.logger.info("Information collected successfully!")
         self.critical = threshold
         self.method = method
         self.containers = check_containers
@@ -114,6 +113,7 @@ class PyLookout:
         """
         self._adjust_message()
         if self.method == "local":
+            print(self.info.logins)
             for notification in self.notification:
                 self.logger.info(notification)
         elif self.method == "simplepush":
@@ -134,6 +134,18 @@ class PyLookout:
                     f"{container['status'].upper()}"
                 )
 
+    def _add_login_info(self):
+        """
+        Add login information to notification message.
+        """
+        if self.info.logins:
+            user_ips = ""
+            for login in self.info.logins:
+                user_ips += f"{login['user']}->{login['ip']} "
+            self.notification.append(
+                f"{len(self.info.logins)} active logins: {user_ips}"
+            )
+
     def _stressed(self, metric, percent):
         """
         Compare a metric with the critical value.
@@ -157,6 +169,8 @@ class PyLookout:
         if self.containers:
             self._containers_status(self.info.containers)
 
+        self._add_login_info()
+
         if self.notification:
             self._notify()
 
